@@ -33,7 +33,7 @@ if __name__ == '__main__':
 
     # scan all ips
     print('scan ports for found IPs...')
-    procs_num = max(len(ips), 10)
+    procs_num = min(len(ips), 10)
     pool = ThreadPool(processes=procs_num)
     start_t = time()
     procs = {ip: pool.apply_async(scan_ports, (ip, True)) for ip in ips}
