@@ -30,7 +30,7 @@ def port_scanner_thread(ip, ports_batches, open_ports, lock):
                 pass
 
 
-def scan_ports(ip):
+def scan_ports(ip, log=False):
     ports_batches = [range(i, min(i+100, 65535)) for i in range(1, 65535, 500)]
     open_ports = []
     lock = threading.Lock()
@@ -40,6 +40,9 @@ def scan_ports(ip):
     for t in threads:
         t.join()
 
+    if log:
+        print(f"{ip}\t=> {','.join([str(p) for p in open_ports])}")
+
     return open_ports
 
 
